containertools.report_container_modifications_as_string
=======================================================

.. autofunction:: abjad.tools.containertools.report_container_modifications_as_string.report_container_modifications_as_string
